==> localnews-news-model-1.3.0.2-sources.jar: com/bxm/localnews/news/dto/VideoDto.java <==
package com.bxm.localnews.news.dto;

import com.bxm.newidea.component.vo.BaseBean;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel(description = "视频信息返回到前端的封装参数")
public class VideoDto extends BaseBean {

    @ApiModelProperty("视频ID")
    private Long id;

    @ApiModelProperty("视频显示图片")
    private String videoImg;

    @ApiModelProperty("视频文件播放地址")
    private String videoUrl;

    @ApiModelProperty("视频标题")
    private String title;

    @ApiModelProperty("视频描述")
    private String description;

    @ApiModelProperty("点击次数（播放次数）")
    private Long clickCount = 0L;

    @ApiModelProperty("点赞次数")
    private Long likeCount = 0L;

    @ApiModelProperty("作者名称")
    private String author;

    @ApiModelProperty("作者头像")
    private String authorImg;

    @ApiModelProperty("该视频当前用户是否已点赞")
    private Boolean praise;

    @ApiModelProperty("评论总数")
    private Long commentCount = 0L;

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public String getAuthorImg() {
        return authorImg;
    }

    public void setAuthorImg(String authorImg) {
        this.authorImg = authorImg;
    }

    public Boolean getPraise() {
        return praise;
    }

    public void setPraise(Boolean praise) {
        this.praise = praise;
    }

    public Long getCommentCount() {
        return commentCount;
    }

    public void setCommentCount(Long commentCount) {
        this.commentCount = commentCount;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getVideoImg() {
        return videoImg;
    }

    public void setVideoImg(String videoImg) {
        this.videoImg = videoImg;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

}

==> localnews-news-model-1.3.2-sources.jar: com/bxm/localnews/news/dto/VideoDto.java <==
package com.bxm.localnews.news.dto;

import com.bxm.newidea.component.vo.BaseBean;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel(description = "视频信息返回到前端的封装参数")
public class VideoDto extends BaseBean {

    @ApiModelProperty("视频ID")
    private Long id;

    @ApiModelProperty("视频显示图片")
    private String videoImg;

    @ApiModelProperty("视频文件播放地址")
    private String videoUrl;

    @ApiModelProperty("视频标题")
    private String title;

    @ApiModelProperty("视频描述")
    private String description;

    @ApiModelProperty("点击次数（播放次数）")
    private Long clickCount = 0L;

    @ApiModelProperty("点赞次数")
    private Long likeCount = 0L;

    @ApiModelProperty("作者名称")
    private String author;

    @ApiModelProperty("作者头像")
    private String authorImg;

    @ApiModelProperty("该视频当前用户是否已点赞")
    private Boolean praise;

    @ApiModelProperty("评论总数")
    private Long commentCount = 0L;

    @ApiModelProperty("高宽比")
    private Double widthRatio;

    public Double getWidthRatio() {
        return widthRatio;
    }

    public void setWidthRatio(Double widthRatio) {
        this.widthRatio = widthRatio;
    }

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public String getAuthorImg() {
        return authorImg;
    }

    public void setAuthorImg(String authorImg) {
        this.authorImg = authorImg;
    }

    public Boolean getPraise() {
        return praise;
    }

    public void setPraise(Boolean praise) {
        this.praise = praise;
    }

    public Long getCommentCount() {
        return commentCount;
    }

    public void setCommentCount(Long commentCount) {
        this.commentCount = commentCount;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getVideoImg() {
        return videoImg;
    }

    public void setVideoImg(String videoImg) {
        this.videoImg = videoImg;
    }

    public String getVideoUrl() {
        return videoUrl;
    }

    public void setVideoUrl(String videoUrl) {
        this.videoUrl = videoUrl;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Long getLikeCount() {
        return likeCount;
    }

    public void setLikeCount(Long likeCount) {
        this.likeCount = likeCount;
    }

}
